@@ -1,12 +1,23 @@
+/*
+    This file is part of Photoflare.
+
+    Photoflare is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    Photoflare is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with Photoflare.  If not, see <https://www.gnu.org/licenses/>.
+*/
+
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
-/*
-
-  Settings class for the PhotoFlare application.
-
-*/
-
 #include <QObject>
 
 #define SETTINGS Settings::instance()
@@ -52,6 +63,8 @@ public:
     QString getHistoryLimit() const;
     void setDockLayout(const QString val);
     QString getDockLayout() const;
+    void setZoomDirection(const QString val);
+    QString getZoomDirection() const;
     void setMemParamsEnabled(bool enabled);
     bool getMemParamsEnabled() const;
     void setUnit(int);
