@@ -99,7 +99,9 @@ PrefsDialog::PrefsDialog(QWidget *parent) :
               << tr("Sweden")
               << tr("Russian")
               << tr("Indonesian")
-              << tr("Spanish");
+              << tr("Spanish")
+              << tr("Japanese")
+              << tr("Turkish");
 
     ui->comboBoxLanguage->addItems(languages);
     addFlagIcons(languages.count());
@@ -133,6 +135,10 @@ PrefsDialog::PrefsDialog(QWidget *parent) :
         ui->comboBoxLanguage->setCurrentIndex(11);
     else if(SETTINGS->getUserLanguage() == "es")
         ui->comboBoxLanguage->setCurrentIndex(12);
+    else if(SETTINGS->getUserLanguage() == "ja")
+        ui->comboBoxLanguage->setCurrentIndex(13);
+    else if(SETTINGS->getUserLanguage() == "tr")
+        ui->comboBoxLanguage->setCurrentIndex(14);
 
     ui->restartButton->hide();
 }
@@ -183,12 +189,7 @@ void PrefsDialog::on_buttonBox_accepted()
 
 void PrefsDialog::on_buttonBox_rejected()
 {
-    // Setup Default settings
-    QString loc = QStandardPaths::locate(QStandardPaths::ConfigLocation, QString(), QStandardPaths::LocateDirectory)+"photoflare";
-    if(QDir(loc).exists() == false)
-    {
-        SETTINGS->setDefaultSettings();
-    }
+    close();
 }
 
 void PrefsDialog::on_openFolderButton_clicked()
@@ -276,6 +277,10 @@ void PrefsDialog::set_user_language()
         SETTINGS->setUserLanguage("id");
     else if(ui->comboBoxLanguage->currentIndex() == 12)
         SETTINGS->setUserLanguage("es");
+    else if(ui->comboBoxLanguage->currentIndex() == 13)
+        SETTINGS->setUserLanguage("ja");
+    else if(ui->comboBoxLanguage->currentIndex() == 14)
+        SETTINGS->setUserLanguage("tr");
 }
 
 void PrefsDialog::addFlagIcons(int languages)
@@ -293,7 +298,9 @@ void PrefsDialog::addFlagIcons(int languages)
           << "Sweden"
           << "Russia"
           << "Indonesia"
-          << "Spain";
+          << "Spain"
+          << "Japan"
+          << "Turkey";
 
     for (int i = 0; i < languages; ++i) {
         ui->comboBoxLanguage->setItemIcon(i,QIcon(flagPath+files[i]+".png"));
