@@ -62,6 +62,7 @@
 #include "managers/ToolManager.h"
 #include "managers/FilterManager.h"
 
+#include "qpainterpath.h"
 #include "widgets/PaintWidget.h"
 #include "dialogs/NewDialog.h"
 #include "dialogs/aboutdialog.h"
@@ -237,8 +238,13 @@ void MainWindow::connectTools()
     ERASER_TOOL->setSecondaryColor(ui->colorBoxWidget->secondaryColor());
     QObject::connect(ui->colorBoxWidget, &ColorBoxWidget::secondaryColorChanged, ERASER_TOOL, &EraserTool::setSecondaryColor);
 
+    MOUSE_POINTER->setFillColor(ui->colorBoxWidget->primaryColor());
+    QObject::connect(ui->colorBoxWidget, &ColorBoxWidget::primaryColorChanged, MOUSE_POINTER, &PointerTool::setFillColor);
+
     // Connect PointerTool signals
     QObject::connect(MOUSE_POINTER, SIGNAL(crop(const QRect&)), this, SLOT(onCrop(const QRect&)));
+    QObject::connect(MOUSE_POINTER, SIGNAL(strokeRect(const QRect&, const QColor&, const int&)), this, SLOT(onStrokeRect(const QRect&, const QColor&, const int&)));
+    QObject::connect(MOUSE_POINTER, SIGNAL(fillRect(const QRect&, const QColor&)), this, SLOT(onFillRect(const QRect&, const QColor&)));
     QObject::connect(MOUSE_POINTER, SIGNAL(save()), this, SLOT(on_actionSave_triggered()));
     QObject::connect(MOUSE_POINTER, SIGNAL(saveAs()), this, SLOT(on_actionSave_As_triggered()));
     QObject::connect(MOUSE_POINTER, SIGNAL(close()), this, SLOT(on_actionClose_triggered()));
@@ -1118,6 +1124,7 @@ void MainWindow::on_actionShow_selection_triggered(bool checked)
     {
         widget->setSelectionVisible(checked);
         ui->actionCrop->setEnabled(checked && widget->isSelectionVisible());
+        ui->actionFill_Rect->setEnabled(checked && widget->isSelectionVisible());
     }
 }
 
@@ -1133,6 +1140,7 @@ void MainWindow::on_actionSelect_all_triggered()
 void MainWindow::onSelectionChanged(bool visible)
 {
     ui->actionCrop->setEnabled(ui->actionShow_selection->isChecked() && visible);
+    ui->actionFill_Rect->setEnabled(ui->actionShow_selection->isChecked() && visible);
     ui->actionShow_selection->setChecked(visible);
 }
 
@@ -1862,6 +1870,68 @@ void MainWindow::onCrop(const QRect& rect)
     }
 }
 
+void MainWindow::on_actionFill_Rect_triggered()
+{
+    PaintWidget *widget = getCurrentPaintWidget();
+    if (widget)
+    {
+        MOUSE_POINTER->onFillRect();
+        widget->onSelectionChanged(QPolygon());
+    }
+}
+
+void MainWindow::onFillRect(const QRect& rect, const QColor& fillColor)
+{
+    PaintWidget *widget = getCurrentPaintWidget();
+    if (widget)
+    {
+        QPainter painter;
+        QImage tmpImage = widget->image();
+        if (!painter.begin(&tmpImage))
+        {
+            qWarning("Failed to begin QPainter");
+            return;
+        }
+
+        QRect fillRect = tmpImage.rect().intersected(rect);
+        painter.fillRect(fillRect, fillColor);
+        painter.end();
+        widget->setImage(tmpImage);
+    }
+}
+
+void MainWindow::on_actionStroke_Rect_triggered()
+{
+    PaintWidget *widget = getCurrentPaintWidget();
+    if (widget)
+    {
+        MOUSE_POINTER->onStrokeRect();
+        widget->onSelectionChanged(QPolygon());
+    }
+}
+
+void MainWindow::onStrokeRect(const QRect& rect, const QColor& fillColor, const int& strokeWidth)
+{
+    PaintWidget *widget = getCurrentPaintWidget();
+    if (widget)
+    {
+        QPainter painter;
+        QImage tmpImage = widget->image();
+        if (!painter.begin(&tmpImage))
+        {
+            qWarning("Failed to begin QPainter");
+            return;
+        }
+        QRect fillRect = tmpImage.rect().intersected(rect);
+        QPainterPath path;
+        path.addRect(fillRect);
+        QPen strokePen(fillColor, strokeWidth);
+        painter.strokePath(path, strokePen);
+        painter.end();
+        widget->setImage(tmpImage);
+    }
+}
+
 void MainWindow::on_toolButtonDropper_clicked()
 {
     clearToolpalette();
@@ -2066,6 +2136,7 @@ void MainWindow::on_toolButtonSmudge_clicked()
 
 void MainWindow::onPointerToolSettingsChanged()
 {
+    MOUSE_POINTER->setStrokeWidth(m_ptSettingsWidget->strokeWidth());
     MOUSE_POINTER->setStroke(m_ptSettingsWidget->stroke());
     MOUSE_POINTER->setFill(m_ptSettingsWidget->fill());
 }
@@ -2377,6 +2448,7 @@ void MainWindow::createKeyboardShortcuts()
     ui->actionDuplicate->setShortcut(QString("Ctrl+U"));
     ui->actionImage_Size->setShortcut(QString("Ctrl+H"));
     ui->actionCrop->setShortcut(QString("Ctrl+Shift+H"));
+    ui->actionFill_Rect->setShortcut(QString("Ctrl+B"));
     // Selection Menu
     ui->actionSelect_all->setShortcut(QString("Ctrl+A"));
     //View Menu
