@@ -29,7 +29,7 @@ class EraserSettingsWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit EraserSettingsWidget(QWidget *parent = 0);
+    explicit EraserSettingsWidget(QWidget *parent = nullptr);
     ~EraserSettingsWidget();
 
     int radius() const;
