@@ -24,11 +24,10 @@ PointerSettingsWidget::PointerSettingsWidget(QWidget *parent) :
 {
     ui->setupUi(this);
 
+    connect(ui->strokeWidth, SIGNAL(changed()), this, SIGNAL(settingsChanged()));
     connect(ui->checkBoxStroke, SIGNAL(clicked()), this, SIGNAL(settingsChanged()));
     connect(ui->checkBoxFill, SIGNAL(clicked()), this, SIGNAL(settingsChanged()));
 
-    ui->checkBoxStroke->setHidden(true);
-    ui->checkBoxFill->setHidden(true);
     ui->square_sel->setHidden(true); // Hide until we have more selection types available
     ui->circle_sel->setHidden(true);
 }
@@ -65,3 +64,32 @@ void PointerSettingsWidget::on_circle_sel_clicked(bool checked)
         ui->circle_sel->setChecked(true);
     }
 }
+
+void PointerSettingsWidget::on_checkBoxStroke_clicked(bool checked)
+{
+    if(checked)
+    {
+        ui->checkBoxFill->setChecked(false);
+    }
+}
+
+
+void PointerSettingsWidget::on_checkBoxFill_clicked(bool checked)
+{
+    if(checked)
+    {
+        ui->checkBoxStroke->setChecked(false);
+    }
+}
+
+int PointerSettingsWidget::strokeWidth() const
+{
+    return ui->strokeWidth->value();
+}
+
+
+void PointerSettingsWidget::on_strokeWidth_valueChanged(int width)
+{
+    //stroke width changed;
+}
+
