@@ -18,7 +18,6 @@
 // MagicWandTool - Select areas on the image.
 
 #include "MagicWandTool.h"
-#include "../mainwindow.h"
 #include "../widgets/PaintWidget.h"
 
 class MagicWandToolPrivate
@@ -29,11 +28,6 @@ public:
         tolerance = 0;
         color = false;
     }
-
-    ~MagicWandToolPrivate()
-    {
-    }
-
     int tolerance;
     bool color;
 };
@@ -41,9 +35,7 @@ public:
 
 MagicWandTool::MagicWandTool(QObject *parent)
     : Tool(parent)
-    , d(new MagicWandToolPrivate)
-{
-}
+    , d(new MagicWandToolPrivate){}
 
 MagicWandTool::~MagicWandTool()
 {
@@ -56,23 +48,6 @@ void MagicWandTool::onMousePress(const QPoint &pos, Qt::MouseButton button)
     {
         case Qt::LeftButton:
             emit selectPrimaryColor(pos, d->tolerance, d->color);
-//            if(m_paintDevice)
-//            {
-//                const QImage *image = dynamic_cast<QImage*>(m_paintDevice);
-//                QImage surface = QImage(image->size(), QImage::Format_ARGB32_Premultiplied);
-//                QPainter painter(&surface);
-//                painter.setCompositionMode(QPainter::CompositionMode_Source);
-//                painter.fillRect(surface.rect(), Qt::transparent);
-//                QPen pen = QPen(QBrush(), 1, Qt::DashLine);
-//                pen.setColor(Qt::gray);
-//                painter.setPen(pen);
-
-//                painter.drawPolygon(d->selection, Qt::WindingFill);
-//                painter.drawRect(d->selection.boundingRect());
-//                painter.end();
-
-//                emit overlaid(m_paintDevice, surface, QPainter::CompositionMode_Difference);
-//            }
             break;
         case Qt::RightButton:
             break;
@@ -83,7 +58,6 @@ void MagicWandTool::onMousePress(const QPoint &pos, Qt::MouseButton button)
 
 void MagicWandTool::setSelection(const QPolygon& poly)
 {
-    //d->selection = poly;
     emit selectionChanged(poly);
     emit painted(m_paintDevice);
 }
