@@ -31,10 +31,6 @@ public:
         primaryPen = QPen(QBrush(), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
         secondaryPen = QPen(QBrush(), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
     }
-    ~PaintBrushAdvToolPrivate()
-    {
-    }
-
     QPoint lastPos;
     QPen primaryPen;
     QPen secondaryPen;
@@ -50,9 +46,7 @@ public:
 
 PaintBrushAdvTool::PaintBrushAdvTool(QObject *parent)
     : Tool(parent)
-    , d(new PaintBrushAdvToolPrivate)
-{
-}
+    , d(new PaintBrushAdvToolPrivate){}
 
 PaintBrushAdvTool::~PaintBrushAdvTool()
 {
@@ -195,7 +189,6 @@ void PaintBrushAdvTool::onMouseMove(const QPoint &pos)
         if(d->fade)
             d->opacity = d->opacity - 0.01f;
 
-
         d->lastPos = pos;
         emit painted(m_paintDevice);
     }
